@@ -6,6 +6,7 @@ import pytest
 
 from faker.providers.color import RandomColor
 from faker.providers.color.bg_BG import Provider as BgBgColorProvider
+from faker.providers.color.el_GR import Provider as ElGrColorProvider
 from faker.providers.color.es_ES import Provider as EsEsColorProvider
 from faker.providers.color.fa_IR import Provider as FaIrColorProvider
 from faker.providers.color.he_IL import Provider as HeILColorProvider
@@ -295,6 +296,21 @@ class TestBgBg:
             assert safe_color_name in BgBgColorProvider.safe_colors
 
 
+class TestElGr:
+    """Test el_GR color provider methods"""
+    def test_color_name(self, faker, num_samples):
+        for _ in range(num_samples):
+            color_name = faker.color_name()
+            assert isinstance(color_name, str)
+            assert color_name in ElGrColorProvider.all_colors.keys()
+
+    def test_safe_color_name(self, faker, num_samples):
+        for _ in range(num_samples):
+            safe_color_name = faker.safe_color_name()
+            assert isinstance(safe_color_name, str)
+            assert safe_color_name in ElGrColorProvider.safe_colors
+
+
 class TestEsEs:
     """Test es_ES color provider methods"""
 
